[Bf-blender-cvs] [84d03a1298c] master: Fix T88755: Reuse Temp Windows by Type not Title

Harley Acheson noreply at git.blender.org
Thu Sep 9 18:27:58 CEST 2021


Commit: 84d03a1298c170a3cd61c8c7f9a0177da8fcfc35
Author: Harley Acheson
Date:   Thu Sep 9 09:26:44 2021 -0700
Branches: master
https://developer.blender.org/rB84d03a1298c170a3cd61c8c7f9a0177da8fcfc35

Fix T88755: Reuse Temp Windows by Type not Title

Reuse temporary windows when they share the same single area type, not
because they share the same title.

See D12401 for more details.

Differential Revision: https://developer.blender.org/D12401

Reviewed by Campbell Barton

===================================================================

M	source/blender/windowmanager/intern/wm_window.c

===================================================================

diff --git a/source/blender/windowmanager/intern/wm_window.c b/source/blender/windowmanager/intern/wm_window.c
index 004a845c667..0402b0d778a 100644
--- a/source/blender/windowmanager/intern/wm_window.c
+++ b/source/blender/windowmanager/intern/wm_window.c
@@ -808,16 +808,17 @@ wmWindow *WM_window_open(bContext *C,
   /* changes rect to fit within desktop */
   wm_window_check_size(&rect);
 
   /* Reuse temporary windows when they share the same title. */
   wmWindow *win = NULL;
   if (temp) {
     LISTBASE_FOREACH (wmWindow *, win_iter, &wm->windows) {
-      if (WM_window_is_temp_screen(win_iter)) {
-        char *wintitle = GHOST_GetTitle(win_iter->ghostwin);
-        if (STREQ(title, wintitle)) {
+      const bScreen *screen = WM_window_get_active_screen(win_iter);
+      if (screen && screen->temp && BLI_listbase_is_single(&screen->areabase)) {
+        ScrArea *area = screen->areabase.first;
+        if (space_type == (area->butspacetype ? area->butspacetype : area->spacetype)) {
           win = win_iter;
+          break;
         }
-        free(wintitle);
       }
     }
   }
@@ -808,16 +808,17 @@ wmWindow *WM_window_open(bContext *C,
   wm_window_check_size(&rect);
 
-  /* Reuse temporary windows when they share the same title. */
+  /* Reuse temporary windows when they share the same single area. */
   wmWindow *win = NULL;
   if (temp) {



More information about the Bf-blender-cvs mailing list